@@ -1,58 +1,69 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="ar_SA">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.0">
 <defaultcodec>UTF-8</defaultcodec>
 <context>
     <name>AboutView</name>
     <message>
+        <location filename="../src/AboutView.cpp" line="21"/>
         <source>There&apos;s life outside the browser!</source>
         <translation>هناك حياة خارج المتصفح!</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="22"/>
         <source>Version %1</source>
         <translation>النسخة %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="25"/>
         <source>%1 is Free Software but its development takes precious time.</source>
         <translation>%1 هو برنامج مجاني و لكن برمجته تستهلك وقتا ثمينا.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="26"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
         <translation>‎الرجاء &lt;a href=&apos;%1&apos;&gt;التبرع&lt;/a&gt; لمتابعة تطوير  %2.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="29"/>
         <source>Report bugs and send in your ideas to %1</source>
         <translation>ارسل الاخطاء و الاراء الى %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="33"/>
         <source>Icon designed by %1.</source>
         <translation>صمم الايقونة %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="34"/>
         <source>Compact mode contributed by %1.</source>
         <translation>صمم الواجهة الخفيفة %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="35"/>
         <source>HTTP proxy support contributed by %1.</source>
         <translation>صمم بروكسي HTTP %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="38"/>
         <source>Translated by %1</source>
         <translation>تمت الترجمة بواسطة %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="66"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>نشر هذا البرنامج تحت رخصة  &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="78"/>
         <source>&amp;Close</source>
         <translation>&amp;اقفل</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="18"/>
         <source>About</source>
         <translation>عن البرنامج</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="20"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>ما اردت معرفته عن %1 و لم تستطع ان تسأل</translation>
     </message>
@@ -60,6 +71,7 @@
 <context>
     <name>ClearButton</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="56"/>
         <source>Clear</source>
         <translation>مسح</translation>
     </message>
@@ -67,91 +79,103 @@
 <context>
     <name>DownloadItem</name>
     <message>
+        <location filename="../src/downloaditem.cpp" line="295"/>
         <source>bytes</source>
         <translation>bytes</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="298"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="301"/>
         <source>MB</source>
         <translation>MB</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="317"/>
         <source>bytes/sec</source>
         <translation>bytes/sec</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="320"/>
         <source>KB/sec</source>
         <translation>KB/sec</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="323"/>
         <source>MB/sec</source>
         <translation>MB/sec</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="329"/>
         <source>seconds</source>
         <translation>seconds</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="332"/>
         <source>minutes</source>
         <translation>minutes</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="335"/>
         <source>%4 %5 remaining</source>
         <translation>%4 %5 متبقي</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
-    <message numerus="yes">
-        <source>%n Download(s)</source>
-        <translation>
-            <numerusform>التحميل %n</numerusform>
-            <numerusform>التحميل %n</numerusform>
-            <numerusform>التحميل %n</numerusform>
-            <numerusform>التحميل %n</numerusform>
-            <numerusform>التحميل %n</numerusform>
-            <numerusform>التحميل %n</numerusform>
-        </translation>
-    </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="47"/>
         <source>This is just the demo version of %1.</source>
         <translation>هذه ليست سوى النسخة التجريبية من %1.</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="49"/>
         <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
         <translation>يمكن تحميل الفيديو في أقل من %1  دقيقة بحيث يمكنك اختبار وظيفة التحميل.</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="53"/>
         <source>Continue</source>
         <translation>متابعة</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="54"/>
         <source>Get the full version</source>
         <translation>احصل على النسخة الكاملة</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../src/downloadmanager.cpp" line="126"/>
+        <source>%n Download(s)</source>
+        <translation><numerusform>التحميل %n</numerusform><numerusform>التحميل %n</numerusform><numerusform>التحميل %n</numerusform><numerusform>التحميل %n</numerusform><numerusform>التحميل %n</numerusform><numerusform>التحميل %n</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>DownloadSettings</name>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="14"/>
         <source>Change location...</source>
         <translation>تغيير الموقع...</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="38"/>
         <source>Choose the download location</source>
         <translation>اختر موقع التحميل</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="49"/>
         <source>Download location changed.</source>
         <translation>موقع التحميل تغير.</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="51"/>
         <source>Current downloads will still go in the previous location.</source>
         <translation>التحميل سيتم في الموقع السابق.</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="63"/>
         <source>Downloading to: %1</source>
         <translation>التحميل الى:%1</translation>
     </message>
@@ -159,6 +183,8 @@
 <context>
     <name>DownloadView</name>
     <message>
+        <location filename="../src/downloadview.cpp" line="18"/>
+        <location filename="../src/downloadview.h" line="22"/>
         <source>Downloads</source>
         <translation>التحميلات</translation>
     </message>
@@ -166,50 +192,62 @@
 <context>
     <name>GlobalShortcuts</name>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="16"/>
         <source>Play</source>
         <translation>Play</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="17"/>
         <source>Pause</source>
         <translation>Pause</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="18"/>
         <source>Play/Pause</source>
         <translation>Play/Pause</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="19"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="20"/>
         <source>Stop playing after current track</source>
         <translation>ايقاف تشغيل المقطع الحالي</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="21"/>
         <source>Next track</source>
         <translation>المقطع التالي</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="22"/>
         <source>Previous track</source>
         <translation>المقطع السابق</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="23"/>
         <source>Increase volume</source>
         <translation>رفع الصوت</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="24"/>
         <source>Decrease volume</source>
         <translation>خفض الصوت</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="25"/>
         <source>Mute</source>
         <translation>صامت</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="26"/>
         <source>Seek forward</source>
         <translation>امام</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="27"/>
         <source>Seek backward</source>
         <translation>خلف</translation>
     </message>
@@ -217,18 +255,22 @@
 <context>
     <name>ListModel</name>
     <message>
+        <location filename="../src/ListModel.cpp" line="47"/>
         <source>Searching...</source>
         <translation>جاري البحث...</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="48"/>
         <source>Show %1 More</source>
         <translation>اظهر %1 المزيد</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="49"/>
         <source>No videos</source>
         <translation>لا توجد فيديوات</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="50"/>
         <source>No more videos</source>
         <translation> لا توجد فيديوات اخرى</translation>
     </message>
@@ -236,6 +278,7 @@
 <context>
     <name>LoadingWidget</name>
     <message>
+        <location filename="../src/loadingwidget.cpp" line="71"/>
         <source>Error</source>
         <translation>خطأ</translation>
     </message>
@@ -243,305 +286,375 @@
 <context>
     <name>MainWindow</name>
     <message>
+        <location filename="../src/MainWindow.cpp" line="105"/>
         <source>&amp;Stop</source>
         <translation>&amp;قف</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="106"/>
         <source>Stop playback and go back to the search view</source>
         <translation>وقف التشغيل و العودة لوضع البحث</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="112"/>
         <source>S&amp;kip</source>
         <translation>&amp;القفز</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="113"/>
         <source>Skip to the next video</source>
         <translation>القفز للفيديو التالي</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="119"/>
+        <location filename="../src/MainWindow.cpp" line="644"/>
         <source>&amp;Pause</source>
         <translation>&amp;ايقاف مؤقت</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="120"/>
+        <location filename="../src/MainWindow.cpp" line="645"/>
         <source>Pause playback</source>
         <translation>ايقاف التشغيل</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="126"/>
+        <location filename="../src/MainWindow.cpp" line="728"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;شاشة كاملة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="127"/>
         <source>Go full screen</source>
         <translation>تشغيل شاشة كاملة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="136"/>
         <source>&amp;Compact mode</source>
         <translation>&amp;الواجهة الخفيفة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="137"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>اخفاء القائمة و شريط المهام</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Open the &amp;YouTube page</source>
         <translation>فتح &amp;صفحة YouTube</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Go to the YouTube video page and pause playback</source>
         <translation>اذهب الى صفحة فيديو YouTube و وقف التشغيل</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Copy the YouTube &amp;link</source>
         <translation>نسخ &amp;رابط YouTube</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Copy the current video YouTube link to the clipboard</source>
         <translation>نسخ رابط YouTube الى clipboard</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="159"/>
         <source>Copy the video stream &amp;URL</source>
         <translation>نسخ الفيديو و &amp;الرابط</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="160"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>نسخ رابط الفيديو الى clipboard</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="166"/>
         <source>&amp;Remove</source>
         <translation>&amp;إزالة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="167"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>إزالة الفيديو من القائمة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="173"/>
         <source>Move &amp;Up</source>
         <translation>الرفع الى &amp;اعلى</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="174"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>رفع المقاطع المختارة الى فوق في القائمة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="180"/>
         <source>Move &amp;Down</source>
         <translation>الانزال الى &amp;تحت</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>انزال المقاطع المختارة الى تحت في القائمة</translation>
     </message>
     <message>
-        <source>&amp;Clear recent keywords</source>
-        <translation type="obsolete">&amp;مسح كلمات البحث السابقة</translation>
+        <location filename="../src/MainWindow.cpp" line="187"/>
+        <source>&amp;Clear recent searches</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="192"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>مسح تاريخ البحث. لا يمكن استعادته.</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="197"/>
         <source>&amp;Quit</source>
         <translation>&amp;الانتهاء</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="199"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="200"/>
         <source>Bye</source>
         <translation>مع السلامة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="204"/>
         <source>&amp;Website</source>
         <translation>&amp;الموقع</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="206"/>
         <source>%1 on the Web</source>
         <translation>%1 على الشبكة</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="210"/>
         <source>Make a &amp;donation</source>
         <translation>&amp;التبرع</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="211"/>
         <source>Please support the continued development of %1</source>
         <translation>‎الرجاء التبرع لمتابعة تطوير  %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="215"/>
         <source>&amp;About</source>
         <translation>&amp;عن البرنامج</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="217"/>
         <source>Info about %1</source>
         <translation>معلومات عن %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="225"/>
         <source>Search</source>
         <translation>البحث</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="244"/>
         <source>Mute volume</source>
         <translation>كتم الصوت</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="246"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+M</translation>
     </message>
     <message>
-        <source>&amp;Application</source>
-        <translation>&amp;البرنامج</translation>
-    </message>
-    <message>
-        <source>&amp;Playlist</source>
-        <translation>&amp;القائمة</translation>
-    </message>
-    <message>
-        <source>&amp;Video</source>
-        <translation>&amp;الفيديو</translation>
-    </message>
-    <message>
-        <source>&amp;Help</source>
-        <translation>&amp;المساعدة</translation>
-    </message>
-    <message>
-        <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation>اضغط %1 لرفع الصوت و %2 لخفضه</translation>
-    </message>
-    <message>
-        <source>Opening %1</source>
-        <translation>جاري فتح %1</translation>
-    </message>
-    <message>
-        <source>Fatal error: %1</source>
-        <translation>خطأ قاتل: %1</translation>
-    </message>
-    <message>
-        <source>Error: %1</source>
-        <translation>خطأ: %1</translation>
-    </message>
-    <message>
-        <source>&amp;Play</source>
-        <translation>&amp;التشغيل</translation>
-    </message>
-    <message>
-        <source>Resume playback</source>
-        <translation>اكمال التشغيل</translation>
-    </message>
-    <message>
-        <source>Exit &amp;Full Screen</source>
-        <translation>الخروج من &amp;الشاشة الكاملة</translation>
-    </message>
-    <message>
-        <source>Remaining time: %1</source>
-        <translation>الوقت المتبقي: %1</translation>
-    </message>
-    <message>
-        <source>Volume at %1%</source>
-        <translation>%1%الصوت عند </translation>
-    </message>
-    <message>
-        <source>Volume is muted</source>
-        <translation>الصوت مكتوم</translation>
-    </message>
-    <message>
-        <source>Volume is unmuted</source>
-        <translation>الصوت غير مكتوم</translation>
-    </message>
-    <message>
-        <source>Maximum video definition set to %1</source>
-        <translation>الوضوح الاقصى %1</translation>
-    </message>
-    <message>
-        <source>Your privacy is now safe</source>
-        <translation>خصوصيتك امنة</translation>
-    </message>
-    <message>
+        <location filename="../src/MainWindow.cpp" line="277"/>
+        <location filename="../src/MainWindow.cpp" line="959"/>
         <source>&amp;Downloads</source>
         <translation>&amp;التحميلات</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="278"/>
         <source>Show details about video downloads</source>
         <translation>عرض تفاصيل عن تحميلات الفيديو</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="286"/>
         <source>&amp;Download</source>
         <translation>&amp;التحميلات</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Download the current video</source>
         <translation>تحميل الفيديو الحالي</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="328"/>
+        <source>&amp;Application</source>
+        <translation>&amp;البرنامج</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="336"/>
+        <source>&amp;Playlist</source>
+        <translation>&amp;القائمة</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="343"/>
+        <source>&amp;Video</source>
+        <translation>&amp;الفيديو</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="362"/>
+        <source>&amp;Help</source>
+        <translation>&amp;المساعدة</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="439"/>
+        <source>Press %1 to raise the volume, %2 to lower it</source>
+        <translation>اضغط %1 لرفع الصوت و %2 لخفضه</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="578"/>
+        <location filename="../src/MainWindow.cpp" line="584"/>
+        <source>Opening %1</source>
+        <translation>جاري فتح %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="597"/>
         <source>Do you want to exit %1 with a download in progress?</source>
         <translation>هل تريد الخروج %1  رغم وجود تحميل?</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="598"/>
         <source>If you close %1 now, this download will be cancelled.</source>
         <translation>عند اغلاق %1 التحميل سيلغى.</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="601"/>
         <source>Close and cancel download</source>
         <translation>الاغلاق و الغاء التحميل</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="602"/>
         <source>Wait for download to finish</source>
         <translation>انتظار انتهاء التحميل</translation>
     </message>
     <message>
-        <source>Downloads complete</source>
-        <translation>التحميل انتهى</translation>
+        <location filename="../src/MainWindow.cpp" line="635"/>
+        <source>Fatal error: %1</source>
+        <translation>خطأ قاتل: %1</translation>
     </message>
     <message>
-        <source>&amp;Clear recent searches</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/MainWindow.cpp" line="637"/>
+        <source>Error: %1</source>
+        <translation>خطأ: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="660"/>
+        <source>&amp;Play</source>
+        <translation>&amp;التشغيل</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="661"/>
+        <source>Resume playback</source>
+        <translation>اكمال التشغيل</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="751"/>
+        <source>Exit &amp;Full Screen</source>
+        <translation>الخروج من &amp;الشاشة الكاملة</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="834"/>
+        <source>Remaining time: %1</source>
+        <translation>الوقت المتبقي: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="892"/>
+        <source>Volume at %1%</source>
+        <translation>%1%الصوت عند </translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="898"/>
+        <source>Volume is muted</source>
+        <translation>الصوت مكتوم</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="901"/>
+        <source>Volume is unmuted</source>
+        <translation>الصوت غير مكتوم</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="908"/>
+        <source>Maximum video definition set to %1</source>
+        <translation>الوضوح الاقصى %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="944"/>
+        <source>Your privacy is now safe</source>
+        <translation>خصوصيتك امنة</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="960"/>
+        <source>Downloads complete</source>
+        <translation>التحميل انتهى</translation>
     </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
+        <location filename="../src/MediaView.cpp" line="33"/>
         <source>Most relevant</source>
         <translation>اقرب النتائج</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="40"/>
         <source>Most recent</source>
         <translation>الاقرب زمنا</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="47"/>
         <source>Most viewed</source>
         <translation>الاكثر عرضا</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="489"/>
         <source>You can now paste the YouTube link into another application</source>
         <translation>يمكنك لصق رابط YouTube في برنامج اخر</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="497"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>يمكنك لصق رابط الفيديو في برنامج اخر</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="498"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>الرابط سيكون صالحا لمدة محدودة.</translation>
     </message>
     <message>
-        <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation type="obsolete">انت تشاهد &quot;%1&quot;</translation>
-    </message>
-    <message>
+        <location filename="../src/MediaView.cpp" line="594"/>
         <source>This is just the demo version of %1.</source>
         <translation>هذه ليست سوى النسخة التجريبية من %1.</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="595"/>
         <source>It allows you to test the application and see if it works for you.</source>
         <translation>انها تتيح لك تجربة البرنامج.</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="598"/>
         <source>Continue</source>
         <translation>متابعة</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="599"/>
         <source>Get the full version</source>
         <translation>احصل على النسخة الكاملة</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="625"/>
         <source>Downloading %1</source>
         <translation>جاري تحميل %1</translation>
     </message>
@@ -549,6 +662,7 @@
 <context>
     <name>NetworkAccess</name>
     <message>
+        <location filename="../src/networkaccess.cpp" line="258"/>
         <source>Network error: %1</source>
         <translation>خطأ شبكة:%1</translation>
     </message>
@@ -556,53 +670,60 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
         <source>%1 views</source>
         <translation>%1 مشاهدات</translation>
     </message>
     <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="obsolete">%1 of %2 (%3) ? %4</translation>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
         <source>Preparing</source>
         <translation>تهيئة</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
         <source>Failed</source>
         <translation>فشل</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
         <source>Completed</source>
         <translation>تم</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
         <source>Stopped</source>
         <translation>متوقف</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
         <source>Stop downloading</source>
         <translation>ايقاف التحميل</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
         <source>Show in %1</source>
         <translation>اظهار في %1</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
         <source>Open parent folder</source>
         <translation>فتح المجلد الرئيسي</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
         <source>Restart downloading</source>
         <translation>اعادة التحميل</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) — %4</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
         <translation>البحث</translation>
     </message>
@@ -610,64 +731,73 @@
 <context>
     <name>SearchView</name>
     <message>
+        <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>مرحبا بك في &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter a keyword to start watching videos.</source>
-        <translation type="obsolete">اختر كلمة بحث للبدء في مشاهدة المقاطع.</translation>
+        <location filename="../src/SearchView.cpp" line="41"/>
+        <source>Get the full version</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="88"/>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="93"/>
+        <source>a keyword</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="94"/>
+        <source>a channel</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="99"/>
+        <source>to start watching videos.</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="124"/>
         <source>Watch</source>
         <translation>شاهد</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="141"/>
         <source>Recent keywords</source>
         <translation>كلمات بحث سابقة</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="159"/>
+        <source>Recent channels</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="358"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
         <translation>تم ايجاد نسخة جديدة من %1 الرجاء &lt;a href=&apos;%2&apos;&gt;الترقية الى نسخة  %3&lt;/a&gt;</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.h" line="35"/>
         <source>Make yourself comfortable</source>
         <translation>اجعل نفسك مرتاحا</translation>
     </message>
-    <message>
-        <source>Get the full version</source>
-        <translation type="unfinished">احصل على النسخة الكاملة</translation>
-    </message>
-    <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>a keyword</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>a channel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Recent channels</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Video</name>
     <message>
+        <location filename="../src/video.cpp" line="186"/>
+        <source>Cannot get video stream for %1</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/video.cpp" line="204"/>
         <source>Network error: %1 for %2</source>
         <translation>خطأ شبكة:%1 الى %2</translation>
     </message>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
