@@ -40,7 +40,7 @@
     <message>
         <location filename="../src/AboutView.cpp" line="35"/>
         <source>HTTP proxy support contributed by %1.</source>
-        <translation/>
+        <translation>Soporte de proxy HTTP aportado por %1</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="38"/>
@@ -293,12 +293,12 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="106"/>
         <source>Stop playback and go back to the search view</source>
-        <translation/>
+        <translation>Parar reproducción y volver a la vista de búsqueda</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="112"/>
         <source>S&amp;kip</source>
-        <translation/>
+        <translation>Sa&amp;ltar</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="113"/>
@@ -315,7 +315,7 @@
         <location filename="../src/MainWindow.cpp" line="120"/>
         <location filename="../src/MainWindow.cpp" line="645"/>
         <source>Pause playback</source>
-        <translation/>
+        <translation>Pausar reproducción</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="126"/>
@@ -336,7 +336,7 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="137"/>
         <source>Hide the playlist and the toolbar</source>
-        <translation/>
+        <translation>Ocultar la lista de reproducción y la barra de herramientas</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="145"/>
@@ -346,7 +346,7 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Go to the YouTube video page and pause playback</source>
-        <translation/>
+        <translation>Ir a la página del vídeo en YouTube y pausar la reproducción</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="152"/>
@@ -356,62 +356,62 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Copy the current video YouTube link to the clipboard</source>
-        <translation/>
+        <translation>Copiar al portapapeles el enlace del vídeo de YouTube actual </translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="159"/>
         <source>Copy the video stream &amp;URL</source>
-        <translation/>
+        <translation>Copiar la &amp;URL del stream de vídeo</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="160"/>
         <source>Copy the current video stream URL to the clipboard</source>
-        <translation/>
+        <translation>Copiar al portapapeles la &amp;URL del stream de vídeo actual</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="166"/>
         <source>&amp;Remove</source>
-        <translation/>
+        <translation>Elimina&amp;r</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="167"/>
         <source>Remove the selected videos from the playlist</source>
-        <translation/>
+        <translation>Eliminar los vídeos seleccionados de la lista de reproducción </translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="173"/>
         <source>Move &amp;Up</source>
-        <translation/>
+        <translation>S&amp;ubir</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="174"/>
         <source>Move up the selected videos in the playlist</source>
-        <translation/>
+        <translation>Subir en la lista de reproducción los vídeos seleccionados</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="180"/>
         <source>Move &amp;Down</source>
-        <translation/>
+        <translation>&amp;Bajar</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="181"/>
         <source>Move down the selected videos in the playlist</source>
-        <translation/>
+        <translation>Bajar en la lista de reproducción los vídeos seleccionados</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="187"/>
         <source>&amp;Clear recent searches</source>
-        <translation/>
+        <translation>&amp;Limpiar las búsquedas recientes</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="192"/>
         <source>Clear the search history. Cannot be undone.</source>
-        <translation/>
+        <translation>Limpiar el historial de búsquedas. Esta acción no puede deshacerse.</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="197"/>
         <source>&amp;Quit</source>
-        <translation/>
+        <translation>&amp;Salir</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="199"/>
@@ -421,42 +421,42 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="200"/>
         <source>Bye</source>
-        <translation/>
+        <translation>Adiós</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="204"/>
         <source>&amp;Website</source>
-        <translation/>
+        <translation>Sitio &amp;Web</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="206"/>
         <source>%1 on the Web</source>
-        <translation/>
+        <translation>%1 en la Web</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="210"/>
         <source>Make a &amp;donation</source>
-        <translation/>
+        <translation>Haz una &amp;donación</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="211"/>
         <source>Please support the continued development of %1</source>
-        <translation/>
+        <translation>Por favor, apoye el continuo desarrollo de %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="215"/>
         <source>&amp;About</source>
-        <translation/>
+        <translation>&amp;Acerca de</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="217"/>
         <source>Info about %1</source>
-        <translation/>
+        <translation>Información sobre %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="225"/>
         <source>Search</source>
-        <translation/>
+        <translation>Búsqueda</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="244"/>
@@ -472,118 +472,118 @@
         <location filename="../src/MainWindow.cpp" line="277"/>
         <location filename="../src/MainWindow.cpp" line="959"/>
         <source>&amp;Downloads</source>
-        <translation/>
+        <translation>&amp;Descargas</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="278"/>
         <source>Show details about video downloads</source>
-        <translation/>
+        <translation>Muestra detalles sobre las descargas de vídeos</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="286"/>
         <source>&amp;Download</source>
-        <translation/>
+        <translation>&amp;Descargar</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Download the current video</source>
-        <translation/>
+        <translation>Descarga el vídeo actual</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="328"/>
         <source>&amp;Application</source>
-        <translation/>
+        <translation>&amp;Aplicación</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="336"/>
         <source>&amp;Playlist</source>
-        <translation/>
+        <translation>Lista de Re&amp;producción</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="343"/>
         <source>&amp;Video</source>
-        <translation/>
+        <translation>&amp;Vídeo</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="362"/>
         <source>&amp;Help</source>
-        <translation/>
+        <translation>&amp;Ayuda</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="439"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation/>
+        <translation>Presiona %1 para subir el volumen, %2 para bajarlo</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="578"/>
         <location filename="../src/MainWindow.cpp" line="584"/>
         <source>Opening %1</source>
-        <translation/>
+        <translation>Abriendo %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="597"/>
         <source>Do you want to exit %1 with a download in progress?</source>
-        <translation/>
+        <translation>¿Deseas salir de %1 con una descarga activa?</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="598"/>
         <source>If you close %1 now, this download will be cancelled.</source>
-        <translation/>
+        <translation>Si cierras %1, esta descarga se cancelará.</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="601"/>
         <source>Close and cancel download</source>
-        <translation/>
+        <translation>Cerrar y cancelar la descarga</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="602"/>
         <source>Wait for download to finish</source>
-        <translation/>
+        <translation>Esperar la finalización de la descarga</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="635"/>
         <source>Fatal error: %1</source>
-        <translation/>
+        <translation>Error fatal: %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="637"/>
         <source>Error: %1</source>
-        <translation/>
+        <translation>Error: %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="660"/>
         <source>&amp;Play</source>
-        <translation/>
+        <translation>Re&amp;producir</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="661"/>
         <source>Resume playback</source>
-        <translation/>
+        <translation>Reiniciar la reproducción</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="751"/>
         <source>Exit &amp;Full Screen</source>
-        <translation/>
+        <translation>Salir de pantalla &amp;completa</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="834"/>
         <source>Remaining time: %1</source>
-        <translation/>
+        <translation>Tiempo restante: %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="892"/>
         <source>Volume at %1%</source>
-        <translation/>
+        <translation>Volumen al %1%</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="898"/>
         <source>Volume is muted</source>
-        <translation/>
+        <translation>El volumen está desactivado</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="901"/>
         <source>Volume is unmuted</source>
-        <translation/>
+        <translation>El volumen está activado</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="908"/>
@@ -598,7 +598,7 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="960"/>
         <source>Downloads complete</source>
-        <translation/>
+        <translation>Descargas completadas</translation>
     </message>
 </context>
 <context>
@@ -606,37 +606,37 @@
     <message>
         <location filename="../src/MediaView.cpp" line="33"/>
         <source>Most relevant</source>
-        <translation/>
+        <translation>Más relevantes</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="40"/>
         <source>Most recent</source>
-        <translation/>
+        <translation>Más recientes</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="47"/>
         <source>Most viewed</source>
-        <translation/>
+        <translation>Más vistos</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="489"/>
         <source>You can now paste the YouTube link into another application</source>
-        <translation/>
+        <translation>Ahora puedes pegar el enlace de Youtube en otra aplicación</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="497"/>
         <source>You can now paste the video stream URL into another application</source>
-        <translation/>
+        <translation>Ahora puedes pegar la URL del stream de vídeo en otra aplicación</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="498"/>
         <source>The link will be valid only for a limited time.</source>
-        <translation/>
+        <translation>EL enlace será válido sólo por un plazo de tiempo limitado.</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="594"/>
         <source>This is just the demo version of %1.</source>
-        <translation/>
+        <translation>Esta es sólo la versión de demo de %1.</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="595"/>
@@ -646,17 +646,17 @@
     <message>
         <location filename="../src/MediaView.cpp" line="598"/>
         <source>Continue</source>
-        <translation/>
+        <translation>Continuar</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="599"/>
         <source>Get the full version</source>
-        <translation/>
+        <translation>Obtener la versión completa</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="625"/>
         <source>Downloading %1</source>
-        <translation/>
+        <translation>Descargand %1</translation>
     </message>
 </context>
 <context>
@@ -664,7 +664,7 @@
     <message>
         <location filename="../src/networkaccess.cpp" line="258"/>
         <source>Network error: %1</source>
-        <translation/>
+        <translation>Error de red: %1</translation>
     </message>
 </context>
 <context>
@@ -672,52 +672,52 @@
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
         <source>%1 views</source>
-        <translation/>
+        <translation>%1 vistas</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
         <source>%1 of %2 (%3) — %4</source>
-        <translation/>
+        <translation>%1 de %2 (%3) -- %4</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
         <source>Preparing</source>
-        <translation/>
+        <translation>Preparando</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
         <source>Failed</source>
-        <translation/>
+        <translation>Falló</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
         <source>Completed</source>
-        <translation/>
+        <translation>Completo</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
         <source>Stopped</source>
-        <translation/>
+        <translation>Parado</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
         <source>Stop downloading</source>
-        <translation/>
+        <translation>Parar descarga</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
         <source>Show in %1</source>
-        <translation/>
+        <translation>Mostrar en %1</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
         <source>Open parent folder</source>
-        <translation/>
+        <translation>Abrir carpeta padre</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
         <source>Restart downloading</source>
-        <translation/>
+        <translation>Reiniciar descarga</translation>
     </message>
 </context>
 <context>
@@ -725,7 +725,7 @@
     <message>
         <location filename="../src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
-        <translation/>
+        <translation>Buscar</translation>
     </message>
 </context>
 <context>
@@ -733,48 +733,48 @@
     <message>
         <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation/>
+        <translation>Bienvenido/a a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="41"/>
         <source>Get the full version</source>
-        <translation/>
+        <translation>Obtener la versión completa</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="88"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation/>
+        <translation>Introducir</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="93"/>
         <source>a keyword</source>
-        <translation/>
+        <translation>una palabra clave</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="94"/>
         <source>a channel</source>
-        <translation/>
+        <translation>un canal</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="99"/>
         <source>to start watching videos.</source>
-        <translation/>
+        <translation>empezar a ver vídeos</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="124"/>
         <source>Watch</source>
-        <translation/>
+        <translation>Ver</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="141"/>
         <source>Recent keywords</source>
-        <translation/>
+        <translation>Palabras clave recientes</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
-        <translation/>
+        <translation>Canales recientes</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="358"/>
@@ -784,7 +784,7 @@
     <message>
         <location filename="../src/SearchView.h" line="35"/>
         <source>Make yourself comfortable</source>
-        <translation/>
+        <translation>Siéntete como en casa</translation>
     </message>
 </context>
 <context>
