@@ -5,22 +5,22 @@
     <message>
         <location filename="../src/AboutView.cpp" line="21"/>
         <source>There&apos;s life outside the browser!</source>
-        <translation>Постоји живот изван интернет претраживача</translation>
+        <translation>Може и без веб прегледача!</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="22"/>
         <source>Version %1</source>
-        <translation>верзија %1</translation>
+        <translation>Верзија %1</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="25"/>
         <source>%1 is Free Software but its development takes precious time.</source>
-        <translation>%1 је Слободан програм, али његово развијање узима драгоцено време</translation>
+        <translation>%1 је слободан софтвер, али његов развој одузма драгоцено време.</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="26"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
-        <translation/>
+        <translation>Молимо да &lt;a href=&apos;%1&apos;&gt;донацијама&lt;/a&gt; подржите развој програма %2.</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="29"/>
@@ -30,32 +30,32 @@
     <message>
         <location filename="../src/AboutView.cpp" line="33"/>
         <source>Icon designed by %1.</source>
-        <translation>Иконицу дизајниро %1</translation>
+        <translation>Иконицу дизајниро %1.</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="34"/>
         <source>Compact mode contributed by %1.</source>
-        <translation/>
+        <translation>Компактни режим допринео %1.</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="35"/>
         <source>HTTP proxy support contributed by %1.</source>
-        <translation/>
+        <translation>Подршку за ХТТП прокси допринео %1.</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="38"/>
         <source>Translated by %1</source>
-        <translation>Превео %1</translation>
+        <translation>Превoдиоци %1</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="66"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
-        <translation>Издат под &lt;a href=&apos;%1&apos;&gt;ГНУ Генерал Публиц Лиценце&lt;/a&gt;</translation>
+        <translation>Под &lt;a href=&apos;%1&apos;&gt;Гнуовом Општом Јавном Лиценцом</translation>
     </message>
     <message>
         <location filename="../src/AboutView.cpp" line="78"/>
         <source>&amp;Close</source>
-        <translation>&amp;amp; Затвори</translation>
+        <translation>&amp;Затвори</translation>
     </message>
     <message>
         <location filename="../src/AboutView.h" line="18"/>
@@ -65,7 +65,7 @@
     <message>
         <location filename="../src/AboutView.h" line="20"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
-        <translation/>
+        <translation>Све што сте одувек желели да знате о програму %1 али се нисте усудили а питате</translation>
     </message>
 </context>
 <context>
@@ -81,32 +81,32 @@
     <message>
         <location filename="../src/downloaditem.cpp" line="295"/>
         <source>bytes</source>
-        <translation>бајтови</translation>
+        <translation>бајтова</translation>
     </message>
     <message>
         <location filename="../src/downloaditem.cpp" line="298"/>
         <source>KB</source>
-        <translation>КБ</translation>
+        <translation>KB</translation>
     </message>
     <message>
         <location filename="../src/downloaditem.cpp" line="301"/>
         <source>MB</source>
-        <translation>МБ</translation>
+        <translation>MB</translation>
     </message>
     <message>
         <location filename="../src/downloaditem.cpp" line="317"/>
         <source>bytes/sec</source>
-        <translation>бајтова / секунди</translation>
+        <translation>b/s</translation>
     </message>
     <message>
         <location filename="../src/downloaditem.cpp" line="320"/>
         <source>KB/sec</source>
-        <translation>КБ / с</translation>
+        <translation>KB/s</translation>
     </message>
     <message>
         <location filename="../src/downloaditem.cpp" line="323"/>
         <source>MB/sec</source>
-        <translation>МБ / сец</translation>
+        <translation>MB/s</translation>
     </message>
     <message>
         <location filename="../src/downloaditem.cpp" line="329"/>
@@ -121,7 +121,7 @@
     <message>
         <location filename="../src/downloaditem.cpp" line="335"/>
         <source>%4 %5 remaining</source>
-        <translation/>
+        <translation>%4 %5 преостаје</translation>
     </message>
 </context>
 <context>
@@ -129,17 +129,17 @@
     <message>
         <location filename="../src/downloadmanager.cpp" line="47"/>
         <source>This is just the demo version of %1.</source>
-        <translation/>
+        <translation>Ово је тек демо верзија  %1.</translation>
     </message>
     <message>
         <location filename="../src/downloadmanager.cpp" line="49"/>
         <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation/>
+        <translation>Може преузети само снимке краће од %1 минута тако да можете испробати употребљивост преузимања.</translation>
     </message>
     <message>
         <location filename="../src/downloadmanager.cpp" line="53"/>
         <source>Continue</source>
-        <translation>Наставити</translation>
+        <translation>Настави</translation>
     </message>
     <message>
         <location filename="../src/downloadmanager.cpp" line="54"/>
@@ -149,7 +149,7 @@
     <message numerus="yes">
         <location filename="../src/downloadmanager.cpp" line="126"/>
         <source>%n Download(s)</source>
-        <translation><numerusform>%n прузимање</numerusform><numerusform>%n прузимања</numerusform><numerusform>%n прузимање</numerusform></translation>
+        <translation><numerusform>%n прузимање</numerusform><numerusform>%n прузимања</numerusform><numerusform>%n прузимања</numerusform></translation>
     </message>
 </context>
 <context>
@@ -157,27 +157,27 @@
     <message>
         <location filename="../src/downloadsettings.cpp" line="14"/>
         <source>Change location...</source>
-        <translation>Промените локацију ...</translation>
+        <translation>Промените локацију...</translation>
     </message>
     <message>
         <location filename="../src/downloadsettings.cpp" line="38"/>
         <source>Choose the download location</source>
-        <translation>Изаберите локацију за преузимање</translation>
+        <translation>Изаберите локацију преузимања</translation>
     </message>
     <message>
         <location filename="../src/downloadsettings.cpp" line="49"/>
         <source>Download location changed.</source>
-        <translation>Локација за преузимање промењена.</translation>
+        <translation>Локација преузимања је промењена.</translation>
     </message>
     <message>
         <location filename="../src/downloadsettings.cpp" line="51"/>
         <source>Current downloads will still go in the previous location.</source>
-        <translation>Тренутна преузимања ће и даље ићи у претходну локацију.</translation>
+        <translation>Тренутна преузимања ће се наставити са претходне локације.</translation>
     </message>
     <message>
         <location filename="../src/downloadsettings.cpp" line="63"/>
         <source>Downloading to: %1</source>
-        <translation/>
+        <translation>Преузимам у: %1</translation>
     </message>
 </context>
 <context>
@@ -199,32 +199,32 @@
     <message>
         <location filename="../src/globalshortcuts.cpp" line="17"/>
         <source>Pause</source>
-        <translation>Пауза</translation>
+        <translation>Паузирај</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="18"/>
         <source>Play/Pause</source>
-        <translation>Репродукуј / Паузирај</translation>
+        <translation>Пусти или паузирај</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="19"/>
         <source>Stop</source>
-        <translation>Стоп</translation>
+        <translation>Заустави</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="20"/>
         <source>Stop playing after current track</source>
-        <translation>Заустављање репродукције након тренутног снимка</translation>
+        <translation>Заустави пуштање након тренутне стазе</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="21"/>
         <source>Next track</source>
-        <translation>Следећи снимак</translation>
+        <translation>Следећа стаза</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="22"/>
         <source>Previous track</source>
-        <translation>Претходни снимак</translation>
+        <translation>Претходна стаза</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="23"/>
@@ -234,22 +234,22 @@
     <message>
         <location filename="../src/globalshortcuts.cpp" line="24"/>
         <source>Decrease volume</source>
-        <translation>Смањи</translation>
+        <translation>Утишај</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="25"/>
         <source>Mute</source>
-        <translation>Муте</translation>
+        <translation>Искључи тон</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="26"/>
         <source>Seek forward</source>
-        <translation>Шалтати напред</translation>
+        <translation>Премотај унапред</translation>
     </message>
     <message>
         <location filename="../src/globalshortcuts.cpp" line="27"/>
         <source>Seek backward</source>
-        <translation>Шалтати назад</translation>
+        <translation>Премотај уназад</translation>
     </message>
 </context>
 <context>
@@ -257,12 +257,12 @@
     <message>
         <location filename="../src/ListModel.cpp" line="47"/>
         <source>Searching...</source>
-        <translation>Претраживање ...</translation>
+        <translation>Тражим...</translation>
     </message>
     <message>
         <location filename="../src/ListModel.cpp" line="48"/>
         <source>Show %1 More</source>
-        <translation/>
+        <translation>Прикажи још %1</translation>
     </message>
     <message>
         <location filename="../src/ListModel.cpp" line="49"/>
@@ -272,7 +272,7 @@
     <message>
         <location filename="../src/ListModel.cpp" line="50"/>
         <source>No more videos</source>
-        <translation>Нема више снимак</translation>
+        <translation>Нема других снимака</translation>
     </message>
 </context>
 <context>
@@ -288,130 +288,130 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="105"/>
         <source>&amp;Stop</source>
-        <translation>Заустави &amp;amp;</translation>
+        <translation>&amp;Заустави</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="106"/>
         <source>Stop playback and go back to the search view</source>
-        <translation>Заустављањи репродукцију и вратиту се на претрагу снимака</translation>
+        <translation>Зауставља пуштање и враћа се на приказ претраге</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="112"/>
         <source>S&amp;kip</source>
-        <translation>Прескочи</translation>
+        <translation>Прес&amp;кочи</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="113"/>
         <source>Skip to the next video</source>
-        <translation>Скочи на следећи снимак</translation>
+        <translation>Пушта следећи снимак</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="119"/>
         <location filename="../src/MainWindow.cpp" line="644"/>
         <source>&amp;Pause</source>
-        <translation>&amp;amp; Паузирај</translation>
+        <translation>&amp;Паузирај</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="120"/>
         <location filename="../src/MainWindow.cpp" line="645"/>
         <source>Pause playback</source>
-        <translation>Пауза репродукције</translation>
+        <translation>Паузира пуштање</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="126"/>
         <location filename="../src/MainWindow.cpp" line="728"/>
         <source>&amp;Full Screen</source>
-        <translation>&amp; Цео екран</translation>
+        <translation>&amp;Целоекрански приказ</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="127"/>
         <source>Go full screen</source>
-        <translation>Отвори преко целог екрана</translation>
+        <translation>Прелази у целоекрански приказ</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="136"/>
         <source>&amp;Compact mode</source>
-        <translation>&amp; компактни режим</translation>
+        <translation>&amp;Компактан режим</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="137"/>
         <source>Hide the playlist and the toolbar</source>
-        <translation>Сакриј плејлисту и траку са алаткама</translation>
+        <translation>Скрива плејлисту и траке алатки</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Open the &amp;YouTube page</source>
-        <translation>Отвори &amp;amp; страницу сајта YouTube</translation>
+        <translation>Отвори страницу на &amp;Јутјубу</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Go to the YouTube video page and pause playback</source>
-        <translation>Иди на YouTube видео страницу и паузирај репродукцију</translation>
+        <translation>Паузира пуштање и одлази на страницу на Јутјубу</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Copy the YouTube &amp;link</source>
-        <translation>Копирање YouTube линка&amp;link</translation>
+        <translation>Копирај ве&amp;зу са Јутјуба</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Copy the current video YouTube link to the clipboard</source>
-        <translation>Копирајте YouTube везу тренутног снимка у клипборд</translation>
+        <translation>Копира Јутјуб везу тренутног видеау у клипборд</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="159"/>
         <source>Copy the video stream &amp;URL</source>
-        <translation>Копирајте УРЛ адресу и видео стрим</translation>
+        <translation>Копирај &amp;УРЛ видео тока</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="160"/>
         <source>Copy the current video stream URL to the clipboard</source>
-        <translation>Копирајте УРЛ тренутног снимка у клипборд</translation>
+        <translation>Копирај УРЛ тренутног видео тока у клипборд</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="166"/>
         <source>&amp;Remove</source>
-        <translation>&amp;amp; Уклони</translation>
+        <translation>&amp;Уклони</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="167"/>
         <source>Remove the selected videos from the playlist</source>
-        <translation>Уклони изабране снимке из плејлисте</translation>
+        <translation>Уклања изабране снимке из плејлисте</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="173"/>
         <source>Move &amp;Up</source>
-        <translation>Помери &amp;amp; Горе</translation>
+        <translation>Помери на&amp;више</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="174"/>
         <source>Move up the selected videos in the playlist</source>
-        <translation>Премести нагоре изабране снимке у Плејлисти</translation>
+        <translation>Помера изабране снимке навише у плејлисти</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="180"/>
         <source>Move &amp;Down</source>
-        <translation>Помери доле</translation>
+        <translation>Помери на&amp;ниже</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="181"/>
         <source>Move down the selected videos in the playlist</source>
-        <translation>Премести надоле изабране снимке у Плејлисти</translation>
+        <translation>Помера изабаране снимке наниже у плејлити</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="187"/>
         <source>&amp;Clear recent searches</source>
-        <translation>&amp;amp; Обриши недавне претраге</translation>
+        <translation>&amp;Уклони недавне претраге</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="192"/>
         <source>Clear the search history. Cannot be undone.</source>
-        <translation>Брисање историје претраге. се не може опозвати.</translation>
+        <translation>Уклања историјат претраге. Не може се опозвати.</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="197"/>
         <source>&amp;Quit</source>
-        <translation>&amp;amp; Затвори</translation>
+        <translation>&amp;Напусти</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="199"/>
@@ -426,32 +426,32 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="204"/>
         <source>&amp;Website</source>
-        <translation>&amp;amp; Сајт</translation>
+        <translation>&amp;Веб сајт</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="206"/>
         <source>%1 on the Web</source>
-        <translation/>
+        <translation>%1 на вебу</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="210"/>
         <source>Make a &amp;donation</source>
-        <translation>Направите  &amp;донацију</translation>
+        <translation>Дајте &amp;донацију</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="211"/>
         <source>Please support the continued development of %1</source>
-        <translation/>
+        <translation>Молимо да подржите даљи развој програма %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="215"/>
         <source>&amp;About</source>
-        <translation>&amp;amp; О програму</translation>
+        <translation>&amp;О програму</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="217"/>
         <source>Info about %1</source>
-        <translation/>
+        <translation>Подаци о програму %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="225"/>
@@ -461,74 +461,74 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="244"/>
         <source>Mute volume</source>
-        <translation>Искључи звука</translation>
+        <translation>Искључи тон</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="246"/>
         <source>Ctrl+M</source>
-        <translation/>
+        <translation>Ctrl + M</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="277"/>
         <location filename="../src/MainWindow.cpp" line="959"/>
         <source>&amp;Downloads</source>
-        <translation>&amp;amp; Преузимања</translation>
+        <translation>&amp;Преузимања</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="278"/>
         <source>Show details about video downloads</source>
-        <translation>Прикажи детаље о преузетим видео снимцима</translation>
+        <translation>Приказује детаље о преузетим видео снимцима</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="286"/>
         <source>&amp;Download</source>
-        <translation>&amp;amp; </translation>
+        <translation>&amp;Преузми</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Download the current video</source>
-        <translation>Преузми тренутни видео</translation>
+        <translation>Преузима тренутни видео</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="328"/>
         <source>&amp;Application</source>
-        <translation/>
+        <translation>&amp;Програм</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="336"/>
         <source>&amp;Playlist</source>
-        <translation>&amp;amp; Плејлиста</translation>
+        <translation>&amp;Плејлиста</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="343"/>
         <source>&amp;Video</source>
-        <translation>&amp; видео</translation>
+        <translation>&amp;Видео</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="362"/>
         <source>&amp;Help</source>
-        <translation>&amp;amp; Помоћ</translation>
+        <translation>&amp;Помоћ</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="439"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation/>
+        <translation>Притисните %1 да би појачали, односно %2 да би утишали тон</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="578"/>
         <location filename="../src/MainWindow.cpp" line="584"/>
         <source>Opening %1</source>
-        <translation/>
+        <translation>Отварам %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="597"/>
         <source>Do you want to exit %1 with a download in progress?</source>
-        <translation/>
+        <translation>Желите ли а напустите %1 током активног преузимања?</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="598"/>
         <source>If you close %1 now, this download will be cancelled.</source>
-        <translation/>
+        <translation>Уколико затворите %1 сада ово преузимање ћњ бити отказано.</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="601"/>
@@ -543,62 +543,62 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="635"/>
         <source>Fatal error: %1</source>
-        <translation/>
+        <translation>Фтална грешка: %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="637"/>
         <source>Error: %1</source>
-        <translation/>
+        <translation>Грешка:%1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="660"/>
         <source>&amp;Play</source>
-        <translation>&amp;amp; Пусти</translation>
+        <translation>&amp;Пусти</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="661"/>
         <source>Resume playback</source>
-        <translation>Настави репродукцију</translation>
+        <translation>Настави пуштање</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="751"/>
         <source>Exit &amp;Full Screen</source>
-        <translation>Изађи из режима целог екрана</translation>
+        <translation>Напусти &amp;целоекрански режим</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="834"/>
         <source>Remaining time: %1</source>
-        <translation/>
+        <translation>Преостало време: %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="892"/>
         <source>Volume at %1%</source>
-        <translation/>
+        <translation>Јачина тона %1%</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="898"/>
         <source>Volume is muted</source>
-        <translation>Звук је искључен</translation>
+        <translation>Тон је искључен</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="901"/>
         <source>Volume is unmuted</source>
-        <translation>Збук је укључен</translation>
+        <translation>Тон  је поново укључен</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="908"/>
         <source>Maximum video definition set to %1</source>
-        <translation/>
+        <translation>Максимална дефиниција видеа је постављена на  %1</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="944"/>
         <source>Your privacy is now safe</source>
-        <translation>Ваша приватност је сада безбедан</translation>
+        <translation>Ваша приватност је сада осигурана</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="960"/>
         <source>Downloads complete</source>
-        <translation>Преузимања завршена</translation>
+        <translation>Преузимања су завршена</translation>
     </message>
 </context>
 <context>
@@ -606,47 +606,47 @@
     <message>
         <location filename="../src/MediaView.cpp" line="33"/>
         <source>Most relevant</source>
-        <translation>Најважније</translation>
+        <translation>Најрелевантнији</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="40"/>
         <source>Most recent</source>
-        <translation>Најновије</translation>
+        <translation>Најновији</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="47"/>
         <source>Most viewed</source>
-        <translation>Најгледаније</translation>
+        <translation>Најгледанији</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="489"/>
         <source>You can now paste the YouTube link into another application</source>
-        <translation>Сада можете да налепите YouTube Линк у другу апликацију</translation>
+        <translation>Сад можете налепити везу са Јутјуба у други програм</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="497"/>
         <source>You can now paste the video stream URL into another application</source>
-        <translation>Сада можете да налепите УРЛ адресу видеа поток у другу апликацију</translation>
+        <translation>Сад можете УРЛ видео тока налепити у други програм</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="498"/>
         <source>The link will be valid only for a limited time.</source>
-        <translation>Линк ће важити само за ограничено време.</translation>
+        <translation>Веза је исправна само одређено време.</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="594"/>
         <source>This is just the demo version of %1.</source>
-        <translation/>
+        <translation>Ово је тек демо верзија %1.</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="595"/>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Она вам омогућава да тестирате апликацију и видите да ли вам одговара.</translation>
+        <translation>Омогућава вам да испробате програм и увидите да ли вам одговара.</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="598"/>
         <source>Continue</source>
-        <translation>Наставити</translation>
+        <translation>Настави</translation>
     </message>
     <message>
         <location filename="../src/MediaView.cpp" line="599"/>
@@ -656,7 +656,7 @@
     <message>
         <location filename="../src/MediaView.cpp" line="625"/>
         <source>Downloading %1</source>
-        <translation/>
+        <translation>преузимам %1</translation>
     </message>
 </context>
 <context>
@@ -664,7 +664,7 @@
     <message>
         <location filename="../src/networkaccess.cpp" line="258"/>
         <source>Network error: %1</source>
-        <translation/>
+        <translation>Мрежна грешка: %1</translation>
     </message>
 </context>
 <context>
@@ -672,22 +672,22 @@
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
         <source>%1 views</source>
-        <translation/>
+        <translation>%1 прегледа</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
         <source>%1 of %2 (%3) — %4</source>
-        <translation/>
+        <translation>%1 од %2 (%3) — %4</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
         <source>Preparing</source>
-        <translation>Припремање</translation>
+        <translation>Припремам</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
         <source>Failed</source>
-        <translation>Није успело</translation>
+        <translation>Неуспех</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
@@ -707,17 +707,17 @@
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
         <source>Show in %1</source>
-        <translation/>
+        <translation>Прикажи у %1</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
         <source>Open parent folder</source>
-        <translation>Отворите родитељски директоријум </translation>
+        <translation>Отвори родитељску фасциклу</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
         <source>Restart downloading</source>
-        <translation>Поново покрените преузимање</translation>
+        <translation>Поново покрени преузимање</translation>
     </message>
 </context>
 <context>
@@ -733,7 +733,7 @@
     <message>
         <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation/>
+        <translation>Добродошли у &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="41"/>
@@ -744,12 +744,12 @@
         <location filename="../src/SearchView.cpp" line="88"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Унесите</translation>
+        <translation>унесите</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="93"/>
         <source>a keyword</source>
-        <translation>Кључна реч</translation>
+        <translation>кључну реч</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="94"/>
@@ -759,7 +759,7 @@
     <message>
         <location filename="../src/SearchView.cpp" line="99"/>
         <source>to start watching videos.</source>
-        <translation>да би сте почели да гледате видео снимке</translation>
+        <translation>да би започели преглед видео снимака.</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="124"/>
@@ -774,17 +774,17 @@
     <message>
         <location filename="../src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
-        <translation>Недавни канала</translation>
+        <translation>Недавни канали</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="358"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
-        <translation/>
+        <translation>Доступна је новија верзија програма %1. &lt;a href=&apos;%2&apos;&gt;Надоградите на верзију %3&lt;/a&gt;</translation>
     </message>
     <message>
         <location filename="../src/SearchView.h" line="35"/>
         <source>Make yourself comfortable</source>
-        <translation>Удобно се сместите</translation>
+        <translation>Раскомотите се</translation>
     </message>
 </context>
 <context>
@@ -792,12 +792,12 @@
     <message>
         <location filename="../src/video.cpp" line="186"/>
         <source>Cannot get video stream for %1</source>
-        <translation/>
+        <translation>не могу да добавим видео ток за %1</translation>
     </message>
     <message>
         <location filename="../src/video.cpp" line="204"/>
         <source>Network error: %1 for %2</source>
-        <translation/>
+        <translation>Мрежна грешка: %1 за %2</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
