@@ -177,7 +177,7 @@
     <message>
         <location filename="../src/downloadsettings.cpp" line="63"/>
         <source>Downloading to: %1</source>
-        <translation/>
+        <translation>Hämtar till: %1</translation>
     </message>
 </context>
 <context>
@@ -461,7 +461,7 @@
     <message>
         <location filename="../src/MainWindow.cpp" line="244"/>
         <source>Mute volume</source>
-        <translation>Mute volym</translation>
+        <translation>Volym av</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="246"/>
@@ -692,32 +692,32 @@
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
         <source>Completed</source>
-        <translation/>
+        <translation>Färdig</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
         <source>Stopped</source>
-        <translation/>
+        <translation>Stoppad</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
         <source>Stop downloading</source>
-        <translation/>
+        <translation>Stoppa nedladdning</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
         <source>Show in %1</source>
-        <translation/>
+        <translation>Visa i %1</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
         <source>Open parent folder</source>
-        <translation/>
+        <translation>Äppna föregående folder</translation>
     </message>
     <message>
         <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
         <source>Restart downloading</source>
-        <translation/>
+        <translation>Omstarta nedladdning</translation>
     </message>
 </context>
 <context>
@@ -725,7 +725,7 @@
     <message>
         <location filename="../src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
-        <translation/>
+        <translation>Sök</translation>
     </message>
 </context>
 <context>
@@ -733,58 +733,58 @@
     <message>
         <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation/>
+        <translation>Välkommen till &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="41"/>
         <source>Get the full version</source>
-        <translation/>
+        <translation>Skaffa den kompletta versionen</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="88"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation/>
+        <translation>Ange</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="93"/>
         <source>a keyword</source>
-        <translation/>
+        <translation>ett sökord</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="94"/>
         <source>a channel</source>
-        <translation/>
+        <translation>en kanal</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="99"/>
         <source>to start watching videos.</source>
-        <translation/>
+        <translation>för att börja titta på video.</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="124"/>
         <source>Watch</source>
-        <translation/>
+        <translation>Titta</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="141"/>
         <source>Recent keywords</source>
-        <translation/>
+        <translation>Senaste sökord</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
-        <translation/>
+        <translation>Senaste kanaler</translation>
     </message>
     <message>
         <location filename="../src/SearchView.cpp" line="358"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
-        <translation/>
+        <translation>En ny version av %1 finns tillgänglig. Vänligen &lt;a href=&apos;%2&apos;&gt;uppdatera till version %3&lt;/a&gt;</translation>
     </message>
     <message>
         <location filename="../src/SearchView.h" line="35"/>
         <source>Make yourself comfortable</source>
-        <translation/>
+        <translation>Gör dig själv bekväm</translation>
     </message>
 </context>
 <context>
@@ -792,12 +792,12 @@
     <message>
         <location filename="../src/video.cpp" line="186"/>
         <source>Cannot get video stream for %1</source>
-        <translation/>
+        <translation>Kan inte få videoström för %1</translation>
     </message>
     <message>
         <location filename="../src/video.cpp" line="204"/>
         <source>Network error: %1 for %2</source>
-        <translation/>
+        <translation>Nätverks fel: %1 för %2</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
