@@ -1,58 +1,69 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="zh_CN" sourcelanguage="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
 <defaultcodec>UTF-8</defaultcodec>
 <context>
     <name>AboutView</name>
     <message>
+        <location filename="../src/AboutView.cpp" line="21"/>
         <source>There&apos;s life outside the browser!</source>
         <translation>浏览器之外，生活亦精彩！</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="22"/>
         <source>Version %1</source>
         <translation>版本：%1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="25"/>
         <source>%1 is Free Software but its development takes precious time.</source>
         <translation>%1 是自由软件。其开发也同样要耗用宝贵时间的。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="26"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
         <translation>恭迎您慷慨&lt;a href=&apos;%1&apos;&gt;捐赠&lt;/a&gt;，支持我们继续开发 %2 。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="29"/>
         <source>Report bugs and send in your ideas to %1</source>
         <translation>软件错误和建议敬请发送到：%1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="33"/>
         <source>Icon designed by %1.</source>
         <translation>图标设计：%1。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="34"/>
         <source>Compact mode contributed by %1.</source>
         <translation>简洁模式贡献者：%1。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="35"/>
         <source>HTTP proxy support contributed by %1.</source>
         <translation>HTTP代理支持贡献者：%1。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="38"/>
         <source>Translated by %1</source>
         <translation>翻译：%1 。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="66"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>本软件遵循&lt;a href=&apos;%1&apos;&gt;GNU通用公共许可证&lt;/a&gt;予以发布。</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="78"/>
         <source>&amp;Close</source>
         <translation>关闭(&amp;C)</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="18"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="20"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>您对 %1 的期望都有什么，还请不吝赐教。</translation>
     </message>
@@ -60,6 +71,7 @@
 <context>
     <name>ClearButton</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="56"/>
         <source>Clear</source>
         <translation>清除</translation>
     </message>
@@ -67,86 +79,103 @@
 <context>
     <name>DownloadItem</name>
     <message>
+        <location filename="../src/downloaditem.cpp" line="295"/>
         <source>bytes</source>
         <translation>字节</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="298"/>
         <source>KB</source>
         <translation>千字节</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="301"/>
         <source>MB</source>
         <translation>兆字节</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="317"/>
         <source>bytes/sec</source>
         <translation>字节/秒</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="320"/>
         <source>KB/sec</source>
         <translation>千字节/秒</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="323"/>
         <source>MB/sec</source>
         <translation>兆字节/秒</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="329"/>
         <source>seconds</source>
         <translation>秒</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="332"/>
         <source>minutes</source>
         <translation>分</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="335"/>
         <source>%4 %5 remaining</source>
         <translation>%4 %5 剩余</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
-    <message numerus="yes">
-        <source>%n Download(s)</source>
-        <translation>
-            <numerusform>下载数：%n</numerusform>
-        </translation>
-    </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="47"/>
         <source>This is just the demo version of %1.</source>
         <translation>这只是 %1 的演示版。</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="49"/>
         <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
         <translation>本版本只能下载 %1 分钟以下的视频，仅用于测试下载功能。</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="53"/>
         <source>Continue</source>
         <translation>继续</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="54"/>
         <source>Get the full version</source>
         <translation>获取完整版</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../src/downloadmanager.cpp" line="126"/>
+        <source>%n Download(s)</source>
+        <translation><numerusform>下载数：%n</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>DownloadSettings</name>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="14"/>
         <source>Change location...</source>
         <translation>更改存储位置……</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="38"/>
         <source>Choose the download location</source>
         <translation>选择下载存储位置</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="49"/>
         <source>Download location changed.</source>
         <translation>下载存储位置已修改。</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="51"/>
         <source>Current downloads will still go in the previous location.</source>
         <translation>当前下载仍然保持前一个存储位置。</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="63"/>
         <source>Downloading to: %1</source>
         <translation>当前下载存储位置：%1</translation>
     </message>
@@ -154,6 +183,8 @@
 <context>
     <name>DownloadView</name>
     <message>
+        <location filename="../src/downloadview.cpp" line="18"/>
+        <location filename="../src/downloadview.h" line="22"/>
         <source>Downloads</source>
         <translation>下载情况</translation>
     </message>
@@ -161,50 +192,62 @@
 <context>
     <name>GlobalShortcuts</name>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="16"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="17"/>
         <source>Pause</source>
         <translation>暂停</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="18"/>
         <source>Play/Pause</source>
         <translation>播放/暂停</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="19"/>
         <source>Stop</source>
         <translation>停止</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="20"/>
         <source>Stop playing after current track</source>
         <translation>当前轨道后停止播放</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="21"/>
         <source>Next track</source>
         <translation>下一轨道</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="22"/>
         <source>Previous track</source>
         <translation>上一轨道</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="23"/>
         <source>Increase volume</source>
         <translation>调高音量</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="24"/>
         <source>Decrease volume</source>
         <translation>调低音量</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="25"/>
         <source>Mute</source>
         <translation>静音</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="26"/>
         <source>Seek forward</source>
         <translation>向前搜索</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="27"/>
         <source>Seek backward</source>
         <translation>向后搜索</translation>
     </message>
@@ -212,18 +255,22 @@
 <context>
     <name>ListModel</name>
     <message>
+        <location filename="../src/ListModel.cpp" line="47"/>
         <source>Searching...</source>
         <translation>搜索中……</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="48"/>
         <source>Show %1 More</source>
         <translation>再多显示 %1</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="49"/>
         <source>No videos</source>
         <translation>没有视频</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="50"/>
         <source>No more videos</source>
         <translation>没有更多视频</translation>
     </message>
@@ -231,6 +278,7 @@
 <context>
     <name>LoadingWidget</name>
     <message>
+        <location filename="../src/loadingwidget.cpp" line="71"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
@@ -238,305 +286,375 @@
 <context>
     <name>MainWindow</name>
     <message>
+        <location filename="../src/MainWindow.cpp" line="105"/>
         <source>&amp;Stop</source>
         <translation>停止(&amp;S)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="106"/>
         <source>Stop playback and go back to the search view</source>
         <translation>停止回放并返回搜索视图</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="112"/>
         <source>S&amp;kip</source>
         <translation>跳过(&amp;k)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="113"/>
         <source>Skip to the next video</source>
         <translation>跳至下一视频</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="119"/>
+        <location filename="../src/MainWindow.cpp" line="644"/>
         <source>&amp;Pause</source>
         <translation>暂停(&amp;P)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="120"/>
+        <location filename="../src/MainWindow.cpp" line="645"/>
         <source>Pause playback</source>
         <translation>暂停回放</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="126"/>
+        <location filename="../src/MainWindow.cpp" line="728"/>
         <source>&amp;Full Screen</source>
         <translation>全屏(&amp;F)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="127"/>
         <source>Go full screen</source>
         <translation>全屏播放</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="136"/>
         <source>&amp;Compact mode</source>
         <translation>简洁模式(&amp;C)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="137"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>隐藏播放列表和工具栏</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Open the &amp;YouTube page</source>
         <translation>打开YouTube页面(&amp;Y)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Go to the YouTube video page and pause playback</source>
         <translation>打开YouTube视频页面并暂停回放</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Copy the YouTube &amp;link</source>
         <translation>复制YouTube链接(&amp;l)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Copy the current video YouTube link to the clipboard</source>
         <translation>复制当前视频的YouTube链接到剪贴板中</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="159"/>
         <source>Copy the video stream &amp;URL</source>
         <translation>复制视频流的URL链接(&amp;U)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="160"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>复制当前视频流的URL到剪贴板中</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="166"/>
         <source>&amp;Remove</source>
         <translation>移除(&amp;R)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="167"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>从播放列表中移除选定的视频</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="173"/>
         <source>Move &amp;Up</source>
         <translation>上移(&amp;U)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="174"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>在播放列表中向上移动选定的视频</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="180"/>
         <source>Move &amp;Down</source>
         <translation>下移(&amp;D)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>在播放列表中向下移动选定的视频</translation>
     </message>
     <message>
-        <source>&amp;Clear recent keywords</source>
-        <translation type="obsolete">清除最近使用的关键字词(&amp;C)</translation>
+        <location filename="../src/MainWindow.cpp" line="187"/>
+        <source>&amp;Clear recent searches</source>
+        <translation>清除最近的检索(&amp;C)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="192"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>清除搜索历史。注意：清除的历史不可恢复。</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="197"/>
         <source>&amp;Quit</source>
         <translation>退出(&amp;Q)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="199"/>
         <source>Ctrl+Q</source>
-        <translation></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="200"/>
         <source>Bye</source>
         <translation>再会</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="204"/>
         <source>&amp;Website</source>
         <translation>网站(&amp;W)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="206"/>
         <source>%1 on the Web</source>
         <translation>%1在网站上</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="210"/>
         <source>Make a &amp;donation</source>
         <translation>敬请捐赠(&amp;d)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="211"/>
         <source>Please support the continued development of %1</source>
         <translation>请您支持 %1 的可持续发展。</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="215"/>
         <source>&amp;About</source>
         <translation>关于(&amp;A)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="217"/>
         <source>Info about %1</source>
         <translation>关于 %1 的信息</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="225"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="244"/>
         <source>Mute volume</source>
         <translation>静音</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="246"/>
         <source>Ctrl+M</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>&amp;Application</source>
-        <translation>应用程序(&amp;A)</translation>
-    </message>
-    <message>
-        <source>&amp;Playlist</source>
-        <translation>播放列表(&amp;P)</translation>
-    </message>
-    <message>
-        <source>&amp;Video</source>
-        <translation>视频(&amp;V)</translation>
-    </message>
-    <message>
-        <source>&amp;Help</source>
-        <translation>帮助(&amp;H)</translation>
-    </message>
-    <message>
-        <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation>按住 %1 提高音量，%2 降低音量</translation>
-    </message>
-    <message>
-        <source>Opening %1</source>
-        <translation>正在打开 %1</translation>
-    </message>
-    <message>
-        <source>Fatal error: %1</source>
-        <translation>严重错误：%1</translation>
-    </message>
-    <message>
-        <source>Error: %1</source>
-        <translation>错误：%1</translation>
-    </message>
-    <message>
-        <source>&amp;Play</source>
-        <translation>播放(&amp;P)</translation>
-    </message>
-    <message>
-        <source>Resume playback</source>
-        <translation>继续回放</translation>
-    </message>
-    <message>
-        <source>Exit &amp;Full Screen</source>
-        <translation>退出全屏(&amp;F)</translation>
-    </message>
-    <message>
-        <source>Remaining time: %1</source>
-        <translation>剩余时间：%1</translation>
-    </message>
-    <message>
-        <source>Volume at %1%</source>
-        <translation>音量：%1%</translation>
-    </message>
-    <message>
-        <source>Volume is muted</source>
-        <translation>已设为静音</translation>
-    </message>
-    <message>
-        <source>Volume is unmuted</source>
-        <translation>静音已解除</translation>
-    </message>
-    <message>
-        <source>Maximum video definition set to %1</source>
-        <translation>最大视频定义设置为%1</translation>
-    </message>
-    <message>
-        <source>Your privacy is now safe</source>
-        <translation>您的隐私已受保护</translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="277"/>
+        <location filename="../src/MainWindow.cpp" line="959"/>
         <source>&amp;Downloads</source>
         <translation>下载(&amp;D)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="278"/>
         <source>Show details about video downloads</source>
         <translation>显示视频下载详情</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="286"/>
         <source>&amp;Download</source>
         <translation>下载(&amp;D)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Download the current video</source>
         <translation>下载当前视频</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="328"/>
+        <source>&amp;Application</source>
+        <translation>应用程序(&amp;A)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="336"/>
+        <source>&amp;Playlist</source>
+        <translation>播放列表(&amp;P)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="343"/>
+        <source>&amp;Video</source>
+        <translation>视频(&amp;V)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="362"/>
+        <source>&amp;Help</source>
+        <translation>帮助(&amp;H)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="439"/>
+        <source>Press %1 to raise the volume, %2 to lower it</source>
+        <translation>按住 %1 提高音量，%2 降低音量</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="578"/>
+        <location filename="../src/MainWindow.cpp" line="584"/>
+        <source>Opening %1</source>
+        <translation>正在打开 %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="597"/>
         <source>Do you want to exit %1 with a download in progress?</source>
         <translation>当前还有尚未完成的下载。您确定要退出 %1 吗？</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="598"/>
         <source>If you close %1 now, this download will be cancelled.</source>
         <translation>如果您现在关闭 %1 ，那么本下载将被取消。</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="601"/>
         <source>Close and cancel download</source>
         <translation>关闭并取消下载</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="602"/>
         <source>Wait for download to finish</source>
         <translation>等待下载完成</translation>
     </message>
     <message>
-        <source>Downloads complete</source>
-        <translation>下载完成</translation>
+        <location filename="../src/MainWindow.cpp" line="635"/>
+        <source>Fatal error: %1</source>
+        <translation>严重错误：%1</translation>
     </message>
     <message>
-        <source>&amp;Clear recent searches</source>
-        <translation>清除最近的检索(&amp;C)</translation>
+        <location filename="../src/MainWindow.cpp" line="637"/>
+        <source>Error: %1</source>
+        <translation>错误：%1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="660"/>
+        <source>&amp;Play</source>
+        <translation>播放(&amp;P)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="661"/>
+        <source>Resume playback</source>
+        <translation>继续回放</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="751"/>
+        <source>Exit &amp;Full Screen</source>
+        <translation>退出全屏(&amp;F)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="834"/>
+        <source>Remaining time: %1</source>
+        <translation>剩余时间：%1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="892"/>
+        <source>Volume at %1%</source>
+        <translation>音量：%1%</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="898"/>
+        <source>Volume is muted</source>
+        <translation>已设为静音</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="901"/>
+        <source>Volume is unmuted</source>
+        <translation>静音已解除</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="908"/>
+        <source>Maximum video definition set to %1</source>
+        <translation>最大视频定义设置为%1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="944"/>
+        <source>Your privacy is now safe</source>
+        <translation>您的隐私已受保护</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="960"/>
+        <source>Downloads complete</source>
+        <translation>下载完成</translation>
     </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
+        <location filename="../src/MediaView.cpp" line="33"/>
         <source>Most relevant</source>
         <translation>相关最多</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="40"/>
         <source>Most recent</source>
         <translation>最近</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="47"/>
         <source>Most viewed</source>
         <translation>观看最多</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="489"/>
         <source>You can now paste the YouTube link into another application</source>
         <translation>您现在可以把YouTube的链接粘贴到其他应用了</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="497"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>您现在可以把视频流的链接粘贴到其他应用了</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="498"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>此链接仅能保持短时间的有效性。</translation>
     </message>
     <message>
-        <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation type="obsolete">您正在观看“%1”</translation>
-    </message>
-    <message>
+        <location filename="../src/MediaView.cpp" line="594"/>
         <source>This is just the demo version of %1.</source>
         <translation>这仅是 %1 的演示版。</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="595"/>
         <source>It allows you to test the application and see if it works for you.</source>
         <translation>本版本允许您测试，以确认本应用是否适合您。</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="598"/>
         <source>Continue</source>
         <translation>继续</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="599"/>
         <source>Get the full version</source>
         <translation>获取完整版</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="625"/>
         <source>Downloading %1</source>
         <translation>正在下载 %1</translation>
     </message>
@@ -544,6 +662,7 @@
 <context>
     <name>NetworkAccess</name>
     <message>
+        <location filename="../src/networkaccess.cpp" line="258"/>
         <source>Network error: %1</source>
         <translation>网络错误：%1</translation>
     </message>
@@ -551,49 +670,60 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
         <source>%1 views</source>
         <translation>%1 人次观看</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation>%1 之 %2 (%3) — %4</translation>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
         <source>Preparing</source>
         <translation>准备中</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
         <source>Failed</source>
         <translation>已失败</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
         <source>Completed</source>
         <translation>已完成</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
         <source>Stopped</source>
         <translation>已停止</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
         <source>Stop downloading</source>
         <translation>停止下载</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
         <source>Show in %1</source>
         <translation>显示到 %1</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
         <source>Open parent folder</source>
         <translation>打开上层目录</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
         <source>Restart downloading</source>
         <translation>重新下载</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) — %4</source>
-        <translation>%1 之 %2 (%3) — %4</translation>
-    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
@@ -601,64 +731,73 @@
 <context>
     <name>SearchView</name>
     <message>
+        <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>欢迎使用&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;！</translation>
     </message>
     <message>
-        <source>Enter a keyword to start watching videos.</source>
-        <translation type="obsolete">请输入一个关键字词以开始观看视频。</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>观看</translation>
-    </message>
-    <message>
-        <source>Recent keywords</source>
-        <translation>最近关键字词</translation>
-    </message>
-    <message>
-        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
-        <translation>%1 已有新版本。敬请&lt;a href=&apos;%2&apos;&gt;更新到版本 %3&lt;/a&gt;。</translation>
-    </message>
-    <message>
-        <source>Make yourself comfortable</source>
-        <translation>请您尽情享受吧！</translation>
-    </message>
-    <message>
+        <location filename="../src/SearchView.cpp" line="41"/>
         <source>Get the full version</source>
         <translation>获取完整版</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="88"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
         <translation>输入</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="93"/>
         <source>a keyword</source>
         <translation>关键字</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="94"/>
         <source>a channel</source>
         <translation>频道名称</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="99"/>
         <source>to start watching videos.</source>
         <translation>开始观看视频。</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="124"/>
+        <source>Watch</source>
+        <translation>观看</translation>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="141"/>
+        <source>Recent keywords</source>
+        <translation>最近关键字词</translation>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
         <translation>最近频道</translation>
     </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="358"/>
+        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
+        <translation>%1 已有新版本。敬请&lt;a href=&apos;%2&apos;&gt;更新到版本 %3&lt;/a&gt;。</translation>
+    </message>
+    <message>
+        <location filename="../src/SearchView.h" line="35"/>
+        <source>Make yourself comfortable</source>
+        <translation>请您尽情享受吧！</translation>
+    </message>
 </context>
 <context>
     <name>Video</name>
     <message>
-        <source>Network error: %1 for %2</source>
-        <translation>网络错误：%1。可能原因：%2</translation>
-    </message>
-    <message>
+        <location filename="../src/video.cpp" line="186"/>
         <source>Cannot get video stream for %1</source>
         <translation>无法获得视频流。可能原因：%1</translation>
     </message>
+    <message>
+        <location filename="../src/video.cpp" line="204"/>
+        <source>Network error: %1 for %2</source>
+        <translation>网络错误：%1。可能原因：%2</translation>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
